aboutsummaryrefslogtreecommitdiff
path: root/include/proj/io.hpp
diff options
context:
space:
mode:
authorKristian Evers <kristianevers@gmail.com>2019-09-08 16:22:15 +0200
committerGitHub <noreply@github.com>2019-09-08 16:22:15 +0200
commit051a983319fdb7a422273a786ea240ad612bb6b5 (patch)
treefdce3020a63235f6c4a8b1799b3b695069d73b8a /include/proj/io.hpp
parent73ccf7e1ba2ba9e927c4eaef81f5237fb4f587b2 (diff)
parent024f63731283c0026ad5b4dea4084bc48bbcc6f7 (diff)
downloadPROJ-051a983319fdb7a422273a786ea240ad612bb6b5.tar.gz
PROJ-051a983319fdb7a422273a786ea240ad612bb6b5.zip
Merge pull request #1585 from rouault/replace_2018_by_2019
Use in API and utilities WKT2_2019 instead of WKT2_2018 (fixes #1578)
Diffstat (limited to 'include/proj/io.hpp')
-rw-r--r--include/proj/io.hpp26
1 files changed, 17 insertions, 9 deletions
diff --git a/include/proj/io.hpp b/include/proj/io.hpp
index 5b1a8588..e439b9ef 100644
--- a/include/proj/io.hpp
+++ b/include/proj/io.hpp
@@ -182,18 +182,24 @@ class PROJ_GCC_DLL WKTFormatter {
WKT2_SIMPLIFIED,
WKT2_2015_SIMPLIFIED = WKT2_SIMPLIFIED,
/** Full WKT2 string, conforming to ISO 19162:2018 / OGC 18-010, with
* (\ref WKT2_2018) all possible nodes and new keyword names.
* Non-normative list of differences:
* <ul>
* <li>WKT2_2018 uses GEOGCRS / BASEGEOGCRS keywords for
* GeographicCRS.</li>
* </ul>
*/
- WKT2_2018,
+ WKT2_2019,
- /** WKT2_2018 with the simplification rule of WKT2_SIMPLIFIED */
- WKT2_2018_SIMPLIFIED,
+ /** Deprecated alias for WKT2_2019 */
+ WKT2_2018 = WKT2_2019,
+
+ /** WKT2_2019 with the simplification rule of WKT2_SIMPLIFIED */
+ WKT2_2019_SIMPLIFIED,
+
+ /** Deprecated alias for WKT2_2019_SIMPLIFIED */
+ WKT2_2018_SIMPLIFIED = WKT2_2019_SIMPLIFIED,
/** WKT1 as traditionally output by GDAL, deriving from OGC 01-009.
A notable departure from WKT1_GDAL with respect to OGC 01-009 is
@@ -322,7 +328,7 @@ class PROJ_GCC_DLL WKTFormatter {
};
PROJ_INTERNAL Version version() const;
- PROJ_INTERNAL bool use2018Keywords() const;
+ PROJ_INTERNAL bool use2019Keywords() const;
PROJ_INTERNAL bool useESRIDialect() const;
PROJ_INTERNAL const DatabaseContextPtr &databaseContext() const;
@@ -736,8 +742,10 @@ class PROJ_GCC_DLL WKTParser {
/** Guessed WKT "dialect" */
enum class PROJ_MSVC_DLL WKTGuessedDialect {
- /** \ref WKT2_2018 */
- WKT2_2018,
+ /** \ref WKT2_2019 */
+ WKT2_2019,
+ /** Deprecated alias for WKT2_2019 */
+ WKT2_2018 = WKT2_2019,
/** \ref WKT2_2015 */
WKT2_2015,
/** \ref WKT1 */
@@ -182,18 +182,24 @@ class PROJ_GCC_DLL WKTFormatter {
WKT2_SIMPLIFIED,
WKT2_2015_SIMPLIFIED = WKT2_SIMPLIFIED,
- /** Full WKT2 string, conforming to ISO 19162:2018 / OGC 18-010, with
- * (\ref WKT2_2018) all possible nodes and new keyword names.
+ /** Full WKT2 string, conforming to ISO 19162:2019 / OGC 18-010, with
+ * (\ref WKT2_2019) all possible nodes and new keyword names.
* Non-normative list of differences:
* <ul>
@@ -182,18 +182,24 @@ class PROJ_GCC_DLL WKTFormatter {
* Non-normative list of differences:
* <ul>
- * <li>WKT2_2018 uses GEOGCRS / BASEGEOGCRS keywords for
+ * <li>WKT2_2019 uses GEOGCRS / BASEGEOGCRS keywords for
* GeographicCRS.</li>
* </ul>